@@ -26,15 +26,17 @@ This module contains functions to test the cost volume create by mc_cnn
 import unittest
 import numpy as np
 import torch
-import torch.nn as nn
+from torch import nn
 
 from mc_cnn.run import computes_cost_volume_mc_cnn_fast
 from mc_cnn.model.mc_cnn_accurate import AccMcCnnInfer
+from mc_cnn.model.mc_cnn_fast import FastMcCnn
 from mc_cnn.dataset_generator.middlebury_generator import MiddleburyGenerator
 from mc_cnn.dataset_generator.datas_fusion_contest_generator import DataFusionContestGenerator
+from mc_cnn.weights import get_weights
 
 
-# pylint: disable=no-self-use
+# load-plugins=pylint.extensions.no_self_use
 class TestMCCNN(unittest.TestCase):
     """
     TestMCCNN class allows to test the cost volume create by mc_cnn
@@ -317,7 +319,7 @@ class TestMCCNN(unittest.TestCase):
         training_loader = MiddleburyGenerator("tests/sample_middlebury.hdf5", "tests/images_middlebury.hdf5", cfg)
         # Patch of shape 3, 11, 11
         # With the firt dimension = left patch, right positive patch, right negative patch
-        patch = training_loader.__getitem__(0)
+        patch = training_loader[0]
 
         x_ref_patch = 6
         y_ref_patch = 5
@@ -351,7 +353,7 @@ class TestMCCNN(unittest.TestCase):
         np.testing.assert_array_equal(patch, gt_path)
 
         # negative disparity
-        patch = training_loader.__getitem__(2)
+        patch = training_loader[2]
 
         x_ref_patch = 5
         y_ref_patch = 7
@@ -445,7 +447,7 @@ class TestMCCNN(unittest.TestCase):
         training_loader = DataFusionContestGenerator("tests/sample_dfc.hdf5", "tests/images_dfc.hdf5", cfg)
         # Patch of shape 3, 11, 11
         # With the firt dimension = left patch, right positive patch, right negative patch
-        patch = training_loader.__getitem__(0)
+        patch = training_loader[0]
 
         x_ref_patch = 6
         y_ref_patch = 5
@@ -478,7 +480,7 @@ class TestMCCNN(unittest.TestCase):
         np.testing.assert_array_equal(patch, gt_path)
 
         # negative disparity
-        patch = training_loader.__getitem__(2)
+        patch = training_loader[2]
 
         x_ref_patch = 5
         y_ref_patch = 7
@@ -511,6 +513,40 @@ class TestMCCNN(unittest.TestCase):
         # Check if the calculated patch is equal to the ground truth (same shape and all elements equals)
         np.testing.assert_array_equal(patch, gt_path)
 
+    def test_accessor_weights(self):
+        """
+        Tests whether the get_weights function return the accurate path
+        """
+        device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
+
+        # Load MC-CNN-fast weights trained on Middlebury in the model
+        weights_path = get_weights()
+        assert "mb" in str(weights_path)
+        fast_net = FastMcCnn()
+        fast_net.load_state_dict(torch.load(weights_path, map_location=device)["model"])
+        fast_net.eval()
+
+        # Load MC-CNN-fast weights trained on DFC in the model
+        weights_path = get_weights(training_dataset="dfc")
+        assert "data_fusion_contest" in str(weights_path)
+        net = FastMcCnn()
+        net.load_state_dict(torch.load(weights_path, map_location=device)["model"])
+        net.eval()
+
+        # Load MC-CNN-accurate weights trained on Middlebury in the model
+        weights_path = get_weights(arch="accurate", training_dataset="middlebury")
+        assert "mb" in str(weights_path)
+        net = AccMcCnnInfer()
+        net.load_state_dict(torch.load(weights_path, map_location=device)["model"])
+        net.eval()
+
+        # Load MC-CNN-accurate weights trained on DFC in the model
+        weights_path = get_weights(arch="accurate", training_dataset="dfc")
+        assert "data_fusion_contest" in str(weights_path)
+        net = AccMcCnnInfer()
+        net.load_state_dict(torch.load(weights_path, map_location=device)["model"])
+        net.eval()
+
 
 if __name__ == "__main__":
     unittest.main()
